#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 4482 $
$LastChangedDate:: 2021-06-15 11:04:42 +0200#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
from componentspace.help.sphinx_help import SphinxHelp
from symspace.osutils.pathutils import Paths
from symspace.help.autodoc import AutoDoc


class DeveloperHelp(SphinxHelp):

    def __init__(self, source_dir: str = None, output_dir: str = None):

        if source_dir is None:
            source_dir = Paths.getComponentSpaceRoot()
        if output_dir is None:
            output_dir = os.path.join(Paths.getComponentSpaceRoot(), '_Help')

        super().__init__(source_dir, output_dir)

    @staticmethod
    def writeHead():
        print('\n#############################################')
        print('#       ComponentSpace Help System          #')
        print('#############################################\n')

    def build(self, sys_exit: bool = False):
        packages_path = os.path.join(Paths.getComponentSpaceRoot(), 'src', 'packages')
        autodoc_dir = os.path.join(self.output_dir, '_Packages')
        doc = AutoDoc(autodoc_dir)
        doc.run(packages_path)
        super().build(sys_exit)


if __name__ == '__main__':
    runner = DeveloperHelp.fromCMDParser()
    runner.build(sys_exit=True)
